@@ -5,7 +5,7 @@ use warnings;
 
 use parent qw(Exporter);
 
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 
 =head1 NAME
 
@@ -13,7 +13,7 @@ Tickit::DSL - domain-specific language for Tickit terminal apps
 
 =head1 VERSION
 
-Version 0.022
+version 0.023
 
 =head1 SYNOPSIS
 
@@ -79,8 +79,9 @@ mainly intended for prototyping:
 
 =cut
 
-# spot the odd one out
-use Tickit::Console;
+# spot the odd one out - doesn't install currently, will add back in when
+# this is fixed. https://rt.cpan.org/Public/Bug/Display.html?id=101169
+# use Tickit::Console;
 use Tickit::Widget::Border;
 use Tickit::Widget::Box;
 use Tickit::Widget::Breadcrumb;
@@ -1430,4 +1431,4 @@ Tom Molesworth <cpan@perlsite.co.uk>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2012-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2012-2015. Licensed under the same terms as Perl itself.
